This history lists major release themes. See the GitHub commits
for change details.

5.1.2 / 2015-03-03
------------------
* Session number is obsolete, acquisition date is required.

5.1.1 / 2015-02-20
------------------
* Split out from qiprofile-rest.
